@@ -405,6 +405,7 @@ let beautify_text =
       t
 
 let compute_graph data config =
+  let ignore_indep = Dependencies.get_ignore_indep config in
   let { src_map = sources; bin_map = binaries } =
     filter_affected data is_affected config
   in
@@ -415,7 +416,7 @@ let compute_graph data config =
         M.add name (Package.Name.of_string source) accu)
       binaries M.empty
   in
-  let dep_graph = Dependencies.get_dep_graph sources src_of_bin in
+  let dep_graph = Dependencies.get_dep_graph ~ignore_indep sources src_of_bin in
   let rounds = Dependencies.topo_split dep_graph in
   (rounds, sources, binaries, dep_graph)
 
