@@ -414,11 +414,13 @@ let inject_debcheck_data (bins : Package.binary Package.t PAMap.t) architectures
             arch_ref
         in
         let ((ic, oc) as p) = Unix.open_process dose_debcheck_cmd in
+        let fmt = Format.formatter_of_out_channel oc in
         (* inefficiency: for each architecture, we iterate on all binary
            packages, not only on binary packages of said architectures *)
         PAMap.iter
-          (fun (_, arch) pkg -> if arch = arch_ref then Package.print oc pkg)
+          (fun (_, arch) pkg -> if arch = arch_ref then Package.print fmt pkg)
           bins;
+        Format.pp_print_flush fmt ();
         close_out oc;
         let result = read_debcheck ic in
         (match Unix.close_process p with
