@@ -17,6 +17,12 @@
 (*  <http://www.gnu.org/licenses/>.                                       *)
 (**************************************************************************)
 
+let get_ignore_indep config =
+  match Core.StringMap.find_opt "ignore_indep" config with
+  | Some Types.Etrue -> true
+  | None | Some Efalse -> false
+  | Some _ -> Error.(raise (Unexpected_expression "ignore_indep"))
+
 module M = Package.Map
 module S = Package.Set
 module N = Package.Name
@@ -45,10 +51,10 @@ end
 module C = Graph.Components.Make (G)
 module T = Set.Make (I)
 
-let get_dep_graph src bin =
+let get_dep_graph ?ignore_indep src bin =
   M.mapi
     (fun _ pkg ->
-      let deps = Package.build_depends pkg in
+      let deps = Package.build_depends ?ignore_indep pkg in
       List.fold_left
         (fun accu dep ->
           try S.add (M.find dep bin) accu with Not_found -> accu)
